@@ -11,242 +11,15 @@ use windows::Win32::System::Com::VARIANT;
 use windows::Win32::System::Com::VARIANT_0;
 use windows::Win32::System::Com::VARIANT_0_0;
 use windows::Win32::System::Com::VARIANT_0_0_0;
-use windows::Win32::System::Ole::SafeArrayCopy;
-use windows::Win32::System::Ole::SafeArrayCreateVector;
-use windows::Win32::System::Ole::SafeArrayDestroy;
-use windows::Win32::System::Ole::SafeArrayGetDim;
-use windows::Win32::System::Ole::SafeArrayGetElement;
-use windows::Win32::System::Ole::SafeArrayGetLBound;
-use windows::Win32::System::Ole::SafeArrayGetUBound;
-use windows::Win32::System::Ole::SafeArrayGetVartype;
-use windows::Win32::System::Ole::SafeArrayPutElement;
-use windows::Win32::System::Ole::VARENUM;
-use windows::Win32::System::Ole::VT_ARRAY;
-use windows::Win32::System::Ole::VT_BOOL;
-use windows::Win32::System::Ole::VT_BSTR;
-use windows::Win32::System::Ole::VT_CY;
-use windows::Win32::System::Ole::VT_DATE;
-use windows::Win32::System::Ole::VT_DECIMAL;
-use windows::Win32::System::Ole::VT_DISPATCH;
-use windows::Win32::System::Ole::VT_EMPTY;
-use windows::Win32::System::Ole::VT_ERROR;
-use windows::Win32::System::Ole::VT_HRESULT;
-use windows::Win32::System::Ole::VT_I1;
-use windows::Win32::System::Ole::VT_I2;
-use windows::Win32::System::Ole::VT_I4;
-use windows::Win32::System::Ole::VT_I8;
-use windows::Win32::System::Ole::VT_INT;
-use windows::Win32::System::Ole::VT_LPSTR;
-use windows::Win32::System::Ole::VT_LPWSTR;
-use windows::Win32::System::Ole::VT_NULL;
-use windows::Win32::System::Ole::VT_R4;
-use windows::Win32::System::Ole::VT_R8;
-use windows::Win32::System::Ole::VT_SAFEARRAY;
-use windows::Win32::System::Ole::VT_UI1;
-use windows::Win32::System::Ole::VT_UI2;
-use windows::Win32::System::Ole::VT_UI4;
-use windows::Win32::System::Ole::VT_UI8;
-use windows::Win32::System::Ole::VT_UINT;
-use windows::Win32::System::Ole::VT_UNKNOWN;
-use windows::Win32::System::Ole::VT_VARIANT;
-use windows::Win32::System::Ole::VT_VOID;
-use windows::Win32::System::Ole::VarAbs;
-use windows::Win32::System::Ole::VarAdd;
-use windows::Win32::System::Ole::VarAnd;
-use windows::Win32::System::Ole::VarBoolFromCy;
-use windows::Win32::System::Ole::VarBoolFromDate;
-use windows::Win32::System::Ole::VarBoolFromDec;
-use windows::Win32::System::Ole::VarBoolFromDisp;
-use windows::Win32::System::Ole::VarBoolFromI1;
-use windows::Win32::System::Ole::VarBoolFromI2;
-use windows::Win32::System::Ole::VarBoolFromI4;
-use windows::Win32::System::Ole::VarBoolFromI8;
-use windows::Win32::System::Ole::VarBoolFromR4;
-use windows::Win32::System::Ole::VarBoolFromR8;
-use windows::Win32::System::Ole::VarBoolFromStr;
-use windows::Win32::System::Ole::VarBoolFromUI1;
-use windows::Win32::System::Ole::VarBoolFromUI2;
-use windows::Win32::System::Ole::VarBoolFromUI4;
-use windows::Win32::System::Ole::VarBoolFromUI8;
-use windows::Win32::System::Ole::VarBstrFromBool;
-use windows::Win32::System::Ole::VarBstrFromCy;
-use windows::Win32::System::Ole::VarBstrFromDate;
-use windows::Win32::System::Ole::VarBstrFromDec;
-use windows::Win32::System::Ole::VarBstrFromDisp;
-use windows::Win32::System::Ole::VarBstrFromI1;
-use windows::Win32::System::Ole::VarBstrFromI2;
-use windows::Win32::System::Ole::VarBstrFromI4;
-use windows::Win32::System::Ole::VarBstrFromI8;
-use windows::Win32::System::Ole::VarBstrFromR4;
-use windows::Win32::System::Ole::VarBstrFromR8;
-use windows::Win32::System::Ole::VarBstrFromUI1;
-use windows::Win32::System::Ole::VarBstrFromUI2;
-use windows::Win32::System::Ole::VarBstrFromUI4;
-use windows::Win32::System::Ole::VarBstrFromUI8;
-use windows::Win32::System::Ole::VarDiv;
-use windows::Win32::System::Ole::VarI1FromBool;
-use windows::Win32::System::Ole::VarI1FromCy;
-use windows::Win32::System::Ole::VarI1FromDate;
-use windows::Win32::System::Ole::VarI1FromDec;
-use windows::Win32::System::Ole::VarI1FromDisp;
-use windows::Win32::System::Ole::VarI1FromI2;
-use windows::Win32::System::Ole::VarI1FromI4;
-use windows::Win32::System::Ole::VarI1FromI8;
-use windows::Win32::System::Ole::VarI1FromR4;
-use windows::Win32::System::Ole::VarI1FromR8;
-use windows::Win32::System::Ole::VarI1FromStr;
-use windows::Win32::System::Ole::VarI1FromUI1;
-use windows::Win32::System::Ole::VarI1FromUI2;
-use windows::Win32::System::Ole::VarI1FromUI4;
-use windows::Win32::System::Ole::VarI1FromUI8;
-use windows::Win32::System::Ole::VarI2FromBool;
-use windows::Win32::System::Ole::VarI2FromCy;
-use windows::Win32::System::Ole::VarI2FromDate;
-use windows::Win32::System::Ole::VarI2FromDec;
-use windows::Win32::System::Ole::VarI2FromDisp;
-use windows::Win32::System::Ole::VarI2FromI1;
-use windows::Win32::System::Ole::VarI2FromI4;
-use windows::Win32::System::Ole::VarI2FromI8;
-use windows::Win32::System::Ole::VarI2FromR4;
-use windows::Win32::System::Ole::VarI2FromR8;
-use windows::Win32::System::Ole::VarI2FromStr;
-use windows::Win32::System::Ole::VarI2FromUI1;
-use windows::Win32::System::Ole::VarI2FromUI2;
-use windows::Win32::System::Ole::VarI2FromUI4;
-use windows::Win32::System::Ole::VarI2FromUI8;
-use windows::Win32::System::Ole::VarI4FromBool;
-use windows::Win32::System::Ole::VarI4FromCy;
-use windows::Win32::System::Ole::VarI4FromDate;
-use windows::Win32::System::Ole::VarI4FromDec;
-use windows::Win32::System::Ole::VarI4FromDisp;
-use windows::Win32::System::Ole::VarI4FromI1;
-use windows::Win32::System::Ole::VarI4FromI2;
-use windows::Win32::System::Ole::VarI4FromI8;
-use windows::Win32::System::Ole::VarI4FromR4;
-use windows::Win32::System::Ole::VarI4FromR8;
-use windows::Win32::System::Ole::VarI4FromStr;
-use windows::Win32::System::Ole::VarI4FromUI1;
-use windows::Win32::System::Ole::VarI4FromUI2;
-use windows::Win32::System::Ole::VarI4FromUI4;
-use windows::Win32::System::Ole::VarI4FromUI8;
-use windows::Win32::System::Ole::VarI8FromBool;
-use windows::Win32::System::Ole::VarI8FromCy;
-use windows::Win32::System::Ole::VarI8FromDate;
-use windows::Win32::System::Ole::VarI8FromDec;
-use windows::Win32::System::Ole::VarI8FromDisp;
-use windows::Win32::System::Ole::VarI8FromI1;
-use windows::Win32::System::Ole::VarI8FromI2;
-use windows::Win32::System::Ole::VarI8FromR4;
-use windows::Win32::System::Ole::VarI8FromR8;
-use windows::Win32::System::Ole::VarI8FromStr;
-use windows::Win32::System::Ole::VarI8FromUI1;
-use windows::Win32::System::Ole::VarI8FromUI2;
-use windows::Win32::System::Ole::VarI8FromUI4;
-use windows::Win32::System::Ole::VarI8FromUI8;
-use windows::Win32::System::Ole::VarMod;
-use windows::Win32::System::Ole::VarMul;
-use windows::Win32::System::Ole::VarNeg;
-use windows::Win32::System::Ole::VarNot;
-use windows::Win32::System::Ole::VarOr;
-use windows::Win32::System::Ole::VarR4FromBool;
-use windows::Win32::System::Ole::VarR4FromCy;
-use windows::Win32::System::Ole::VarR4FromDate;
-use windows::Win32::System::Ole::VarR4FromDec;
-use windows::Win32::System::Ole::VarR4FromDisp;
-use windows::Win32::System::Ole::VarR4FromI1;
-use windows::Win32::System::Ole::VarR4FromI2;
-use windows::Win32::System::Ole::VarR4FromI4;
-use windows::Win32::System::Ole::VarR4FromI8;
-use windows::Win32::System::Ole::VarR4FromR8;
-use windows::Win32::System::Ole::VarR4FromStr;
-use windows::Win32::System::Ole::VarR4FromUI1;
-use windows::Win32::System::Ole::VarR4FromUI2;
-use windows::Win32::System::Ole::VarR4FromUI4;
-use windows::Win32::System::Ole::VarR4FromUI8;
-use windows::Win32::System::Ole::VarR8FromBool;
-use windows::Win32::System::Ole::VarR8FromCy;
-use windows::Win32::System::Ole::VarR8FromDate;
-use windows::Win32::System::Ole::VarR8FromDec;
-use windows::Win32::System::Ole::VarR8FromDisp;
-use windows::Win32::System::Ole::VarR8FromI1;
-use windows::Win32::System::Ole::VarR8FromI2;
-use windows::Win32::System::Ole::VarR8FromI4;
-use windows::Win32::System::Ole::VarR8FromI8;
-use windows::Win32::System::Ole::VarR8FromR4;
-use windows::Win32::System::Ole::VarR8FromStr;
-use windows::Win32::System::Ole::VarR8FromUI1;
-use windows::Win32::System::Ole::VarR8FromUI2;
-use windows::Win32::System::Ole::VarR8FromUI4;
-use windows::Win32::System::Ole::VarR8FromUI8;
-use windows::Win32::System::Ole::VarSub;
-use windows::Win32::System::Ole::VarUI1FromBool;
-use windows::Win32::System::Ole::VarUI1FromCy;
-use windows::Win32::System::Ole::VarUI1FromDate;
-use windows::Win32::System::Ole::VarUI1FromDec;
-use windows::Win32::System::Ole::VarUI1FromDisp;
-use windows::Win32::System::Ole::VarUI1FromI1;
-use windows::Win32::System::Ole::VarUI1FromI2;
-use windows::Win32::System::Ole::VarUI1FromI4;
-use windows::Win32::System::Ole::VarUI1FromI8;
-use windows::Win32::System::Ole::VarUI1FromR4;
-use windows::Win32::System::Ole::VarUI1FromR8;
-use windows::Win32::System::Ole::VarUI1FromStr;
-use windows::Win32::System::Ole::VarUI1FromUI2;
-use windows::Win32::System::Ole::VarUI1FromUI4;
-use windows::Win32::System::Ole::VarUI1FromUI8;
-use windows::Win32::System::Ole::VarUI2FromBool;
-use windows::Win32::System::Ole::VarUI2FromCy;
-use windows::Win32::System::Ole::VarUI2FromDate;
-use windows::Win32::System::Ole::VarUI2FromDec;
-use windows::Win32::System::Ole::VarUI2FromDisp;
-use windows::Win32::System::Ole::VarUI2FromI1;
-use windows::Win32::System::Ole::VarUI2FromI2;
-use windows::Win32::System::Ole::VarUI2FromI4;
-use windows::Win32::System::Ole::VarUI2FromI8;
-use windows::Win32::System::Ole::VarUI2FromR4;
-use windows::Win32::System::Ole::VarUI2FromR8;
-use windows::Win32::System::Ole::VarUI2FromStr;
-use windows::Win32::System::Ole::VarUI2FromUI1;
-use windows::Win32::System::Ole::VarUI2FromUI4;
-use windows::Win32::System::Ole::VarUI2FromUI8;
-use windows::Win32::System::Ole::VarUI4FromBool;
-use windows::Win32::System::Ole::VarUI4FromCy;
-use windows::Win32::System::Ole::VarUI4FromDate;
-use windows::Win32::System::Ole::VarUI4FromDec;
-use windows::Win32::System::Ole::VarUI4FromDisp;
-use windows::Win32::System::Ole::VarUI4FromI1;
-use windows::Win32::System::Ole::VarUI4FromI2;
-use windows::Win32::System::Ole::VarUI4FromI4;
-use windows::Win32::System::Ole::VarUI4FromI8;
-use windows::Win32::System::Ole::VarUI4FromR4;
-use windows::Win32::System::Ole::VarUI4FromR8;
-use windows::Win32::System::Ole::VarUI4FromStr;
-use windows::Win32::System::Ole::VarUI4FromUI1;
-use windows::Win32::System::Ole::VarUI4FromUI2;
-use windows::Win32::System::Ole::VarUI4FromUI8;
-use windows::Win32::System::Ole::VarUI8FromBool;
-use windows::Win32::System::Ole::VarUI8FromCy;
-use windows::Win32::System::Ole::VarUI8FromDate;
-use windows::Win32::System::Ole::VarUI8FromDec;
-use windows::Win32::System::Ole::VarUI8FromDisp;
-use windows::Win32::System::Ole::VarUI8FromI1;
-use windows::Win32::System::Ole::VarUI8FromI2;
-use windows::Win32::System::Ole::VarUI8FromI8;
-use windows::Win32::System::Ole::VarUI8FromR4;
-use windows::Win32::System::Ole::VarUI8FromR8;
-use windows::Win32::System::Ole::VarUI8FromStr;
-use windows::Win32::System::Ole::VarUI8FromUI1;
-use windows::Win32::System::Ole::VarUI8FromUI2;
-use windows::Win32::System::Ole::VarUI8FromUI4;
-use windows::Win32::System::Ole::VarXor;
+use windows::Win32::System::Ole::*;
 use windows::core::HRESULT;
 use windows::core::IUnknown;
 use windows::core::PSTR;
 
-use crate::Error;
-use crate::Result;
-use crate::errors::ERR_NULL_PTR;
-use crate::errors::ERR_TYPE;
+use super::Error;
+use super::Result;
+use super::errors::ERR_NULL_PTR;
+use super::errors::ERR_TYPE;
 
 const VARIANT_TRUE: i16 = -1;
 const VARIANT_FALSE: i16 = 0;
